#!/usr/bin/env python
#-*- coding: iso-8859-15 -*-

#################################################################################
## Coban - Module de calculs vido                                             ## 
## Copyright (C) 2008  Stphan GURIN                                          ##
## contact : setthe@tuxfamily.org                                              ##
##                                                                             ##
## This program is free software; you can redistribute it and/or               ##
## modify it under the terms of the GNU General Public License                 ##
## as published by the Free Software Foundation; either version 2              ##
## of the License, or (at your option) any later version.                      ##
##                                                                             ##
## This program is distributed in the hope that it will be useful,             ##
## but WITHOUT ANY WARRANTY; without even the implied warranty of              ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               ##
## GNU General Public License for more details.                                ##
##                                                                             ##
## You should have received a copy of the GNU General Public License           ##
## along with this program; if not, write to the Free Software                 ##
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. ##
#################################################################################

import wx
from math import pi, atan


############################################################################
##                                                                        ##
##                            Module vido                                ##
##                            Version 0.1.1                               ##
##                                                                        ##
##   - permet de calculer des focales en fonction du champ de vision      ##
##     dsir - et l'inverse !                                            ##
##                                                                        ##
##   - ajout de focales supplmentaires                                   ##
##   - rsolution d'un bug d'affichage sous Windows (onglet zoom)         ##
##     --> les rsultats ne dpassent plus du cadre                       ##
##                                                                        ##
##                                                                        ##
############################################################################



# variables globales
version = "0.1.1"
statusText = u"Calcul d'un champ de vision en fonction d'une distance"
listeFocale = ['2.6','2.8','3','3.5','3.6','3.7','4','4.2','4.5','4.8','5','5.5','5.7','5.8','6','6.2','6.3',
               '6.5','7.5','8','8.5','9','9.5','10','12','12.5','15','16','25','38','40','48','50','58','60','75',
               '87','90','100','120','128','140','144','180','240']
listeCapteur = [' 1/4"',' 1/3"',' 1/2"',' 2/3"']




class OngletChamp(wx.Panel):
    """Calcul d'un champ de vision en fonction d'une distance"""
    def __init__(self, parent):
        wx.Panel.__init__(self, parent)
        self.parent = parent
        
        
        ############## cration du sizer principal ###############
        
        self.gbs = wx.GridBagSizer(hgap=5, vgap=5)
        
        ############## cration des widgets #####################
        
        # spinctrl de choix de la distance
        labelDist = wx.StaticText(self, -1, u"Distance sujet/objectif (en m): ")
        self.distance = wx.SpinCtrl(self, -1, "")
        self.distance.SetRange(1,999)
        self.distance.SetValue(20)
        
        # Choix de slection du capteur
        labelCapteur = wx.StaticText(self, -1, u"Format du capteur : ")
        self.lbCapteur = wx.Choice(self, -1, (-1, -1), choices = listeCapteur)
        self.lbCapteur.SetStringSelection(listeCapteur[1])
        
        # ListBox de slection de la focale
        labelFocale = wx.StaticText(self, -1, u"Focale (mm): ")
        self.lbFocale = wx.ListBox(self, -1, (10, 10), (90, 120), listeFocale, wx.LB_SINGLE)
        self.lbFocale.SetStringSelection(listeFocale[11])
        
        # Rsultats
        labelLargeur = wx.StaticText(self, -1, u"Largeur visualise : ")
        self.largeur = wx.StaticText(self, -1, u"....... m")
        self.largeur.SetForegroundColour('blue')
        self.largeur.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        labelHauteur = wx.StaticText(self, -1, u"Hauteur visualise : ")
        self.hauteur = wx.StaticText(self, -1, u"....... m")
        self.hauteur.SetForegroundColour('blue')
        self.hauteur.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        labelAngle = wx.StaticText(self, -1, u"Angle de vision : ")
        self.angle = wx.StaticText(self, -1, u"....... ")
        self.angle.SetForegroundColour('blue')
        self.angle.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        
        # Bouton calcul
        self.btnCalc = wx.Button(self ,-1, "Calculer")
        self.btnCalc.SetBackgroundColour("yellow")
        self.btnCalc.SetDefault()
        self.Bind(wx.EVT_BUTTON, self.onCalcul, self.btnCalc)
        
        ############### Ajout des wigets au sizer ####################
        self.gbs.Add(labelDist, (0,0))
        self.gbs.Add(self.distance, (0,1))
        self.gbs.Add(labelCapteur, (1,0))
        self.gbs.Add(self.lbCapteur, (1,1))
        self.gbs.Add(labelFocale, (2,0))
        self.gbs.Add(self.lbFocale, (2,1))
        self.gbs.Add(labelLargeur, (0,3))
        self.gbs.Add(self.largeur, (0,4))
        self.gbs.Add(labelHauteur, (1,3))
        self.gbs.Add(self.hauteur, (1,4))
        self.gbs.Add(labelAngle, (2,3))
        self.gbs.Add(self.angle, (2,4))
        self.gbs.Add(self.btnCalc, (3,1))
        
        self.SetSizerAndFit(self.gbs)
        
    def onCalcul(self, evt):
        """Calcul d'une largeur & focale en fonction de la hauteur  visualiser"""
        # on rcupre les valeurs ncessaires au calcul
        d = self.distance.GetValue()
        capteur = self.lbCapteur.GetStringSelection()
        focale = self.lbFocale.GetStringSelection()
        # on converti la valeur de la focale (str) en entier (int)
        focale = float(focale)
        # on donne les valeurs  la largeur cible (lc) et la hauteur cible (hc) du capteur
        if capteur == listeCapteur[0]:
            lc = 3.6
            hc = 2.7
        if capteur == listeCapteur[1]:
            lc = 4.8
            hc = 3.6
        if capteur == listeCapteur[2]:
            lc = 6.4
            hc = 4.8
        if capteur == listeCapteur[3]:
            lc = 8.8
            hc = 6.6
        
        # Calcul de la largeur visualise
        lvisu = round((lc*(d/focale)), 1)
        hvisu = round((3*lvisu/4), 1)
        avisu = round(((2*atan(lvisu/(2*d)))*(180/pi)), 1)
        
        # envoie des rsultats dans les statictexts
        self.largeur.SetLabel("%s m" %lvisu)
        self.hauteur.SetLabel("%s m" %hvisu)
        self.angle.SetLabel(u"%s " %avisu)
         
        
class OngletHauteur(wx.Panel):
    def __init__(self, parent):
        wx.Panel.__init__(self, parent)
        self.parent = parent
        
        
        ############## cration du sizer principal ###############
        
        self.gbs = wx.GridBagSizer(hgap=5, vgap=5)
        
        ############## cration des widgets #####################
        
        # spinctrl de choix de la distance
        labelDistance = wx.StaticText(self, -1, u"Distance sujet/objectif (en m): ")
        self.distance = wx.SpinCtrl(self, -1, "")
        self.distance.SetRange(1,999)
        self.distance.SetValue(20)
        
        # Choix de slection du capteur
        labelCapteur = wx.StaticText(self, -1, u"Format du capteur : ")
        self.lbCapteur = wx.Choice(self, -1, (-1, -1), choices = listeCapteur)
        self.lbCapteur.SetStringSelection(listeCapteur[1])
        
        # spinctrl de choix de la hauteur  visualiser
        labelHauteur = wx.StaticText(self, -1, u"Hauteur  visualiser (en m): ")
        self.hauteur = wx.SpinCtrl(self, -1, "")
        self.hauteur.SetRange(1,100)
        self.hauteur.SetValue(3)
        
        # Rsultats
        labelLargeur = wx.StaticText(self, -1, u"Largeur visualise : ")
        self.largeur = wx.StaticText(self, -1, u"....... m")
        self.largeur.SetForegroundColour('blue')
        self.largeur.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        labelAngle = wx.StaticText(self, -1, u"Angle de vision : ")
        self.angle = wx.StaticText(self, -1, u"....... ")
        self.angle.SetForegroundColour('blue')
        self.angle.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        labelFocale = wx.StaticText(self, -1, u"Focale idale : ")
        self.focale = wx.StaticText(self, -1, u"....... mm")
        self.focale.SetForegroundColour('blue')
        self.focale.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        
        # Bouton calcul
        self.btnCalc = wx.Button(self ,-1, "Calculer")
        self.btnCalc.SetBackgroundColour("yellow")
        self.btnCalc.SetDefault()
        self.Bind(wx.EVT_BUTTON, self.onCalcul, self.btnCalc)
        
        ############### Ajout des wigets au sizer ####################
        self.gbs.Add(labelDistance, (0,0))
        self.gbs.Add(self.distance, (0,1))
        self.gbs.Add(labelCapteur, (1,0))
        self.gbs.Add(self.lbCapteur, (1,1))
        self.gbs.Add(labelHauteur, (2,0))
        self.gbs.Add(self.hauteur, (2,1))
        self.gbs.Add(labelLargeur, (0,3))
        self.gbs.Add(self.largeur, (0,4))
        self.gbs.Add(labelAngle, (1,3))
        self.gbs.Add(self.angle, (1,4))
        self.gbs.Add(labelFocale, (2,3))
        self.gbs.Add(self.focale, (2,4))
        self.gbs.Add(self.btnCalc, (3,1))
        
        self.SetSizerAndFit(self.gbs)
        
    def onCalcul(self, evt):
        # on rcupre les valeurs ncessaires au calcul
        d = self.distance.GetValue()
        capteur = self.lbCapteur.GetStringSelection()
        h = self.hauteur.GetValue()
        # on donne les valeurs  la largeur cible (lc) et la hauteur cible (hc) du capteur
        if capteur == listeCapteur[0]:
            lc = 3.6
            hc = 2.7
        if capteur == listeCapteur[1]:
            lc = 4.8
            hc = 3.6
        if capteur == listeCapteur[2]:
            lc = 6.4
            hc = 4.8
        if capteur == listeCapteur[3]:
            lc = 8.8
            hc = 6.6
        
        # Calcul de la largeur visualise
        lvisu = round((4*h/3), 1)
        avisu = round(((2*atan(lvisu/(2*d)))*(180/pi)), 1)
        focal = round((d*(hc/h)), 1)
        
        # envoie des rsultats dans les statictexts
        self.largeur.SetLabel("%s m" %lvisu)
        self.angle.SetLabel(u"%s " %avisu)
        self.focale.SetLabel("%s mm" %focal)


class OngletLargeur(wx.Panel):
    """Calcul d'une hauteur & focale en fonction de la largeur  visualiser"""
    def __init__(self, parent):
        wx.Panel.__init__(self, parent)
        self.parent = parent
        
        
        ############## cration du sizer principal ###############
        
        self.gbs = wx.GridBagSizer(hgap=5, vgap=5)
        
        ############## cration des widgets #####################
        
        # spinctrl de choix de la distance
        labelDistance = wx.StaticText(self, -1, u"Distance sujet/objectif (en m): ")
        self.distance = wx.SpinCtrl(self, -1, "")
        self.distance.SetRange(1,999)
        self.distance.SetValue(20)
        
        # Choix de slection du capteur
        labelCapteur = wx.StaticText(self, -1, u"Format du capteur : ")
        self.lbCapteur = wx.Choice(self, -1, (-1, -1), choices = listeCapteur)
        self.lbCapteur.SetStringSelection(listeCapteur[1])
        
        # spinctrl de choix de la largeur  visualiser
        labelLargeur = wx.StaticText(self, -1, u"Largeur  visualiser (en m): ")
        self.largeur = wx.SpinCtrl(self, -1, "")
        self.largeur.SetRange(1,100)
        self.largeur.SetValue(5)
        
        # Rsultats
        labelHauteur = wx.StaticText(self, -1, u"Hauteur visualise : ")
        self.hauteur = wx.StaticText(self, -1, u"....... m")
        self.hauteur.SetForegroundColour('blue')
        self.hauteur.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        labelAngle = wx.StaticText(self, -1, u"Angle de vision : ")
        self.angle = wx.StaticText(self, -1, u"....... ")
        self.angle.SetForegroundColour('blue')
        self.angle.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        labelFocale = wx.StaticText(self, -1, u"Focale idale : ")
        self.focale = wx.StaticText(self, -1, u"....... mm")
        self.focale.SetForegroundColour('blue')
        self.focale.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        
        # Bouton calcul
        self.btnCalc = wx.Button(self ,-1, "Calculer")
        self.btnCalc.SetBackgroundColour("yellow")
        self.btnCalc.SetDefault()
        self.Bind(wx.EVT_BUTTON, self.onCalcul, self.btnCalc)
        
        ############### Ajout des wigets au sizer ####################
        self.gbs.Add(labelDistance, (0,0))
        self.gbs.Add(self.distance, (0,1))
        self.gbs.Add(labelCapteur, (1,0))
        self.gbs.Add(self.lbCapteur, (1,1))
        self.gbs.Add(labelLargeur, (2,0))
        self.gbs.Add(self.largeur, (2,1))
        self.gbs.Add(labelHauteur, (0,3))
        self.gbs.Add(self.hauteur, (0,4))
        self.gbs.Add(labelAngle, (1,3))
        self.gbs.Add(self.angle, (1,4))
        self.gbs.Add(labelFocale, (2,3))
        self.gbs.Add(self.focale, (2,4))
        self.gbs.Add(self.btnCalc, (3,1))
        
        self.SetSizerAndFit(self.gbs)
        
    def onCalcul(self, evt):
        # on rcupre les valeurs ncessaires au calcul
        d = self.distance.GetValue()
        capteur = self.lbCapteur.GetStringSelection()
        l = float(self.largeur.GetValue())
        # on donne les valeurs  la largeur cible (lc) et la hauteur cible (hc) du capteur
        if capteur == listeCapteur[0]:
            lc = 3.6
            hc = 2.7
        if capteur == listeCapteur[1]:
            lc = 4.8
            hc = 3.6
        if capteur == listeCapteur[2]:
            lc = 6.4
            hc = 4.8
        if capteur == listeCapteur[3]:
            lc = 8.8
            hc = 6.6
        
        # Calcul de la largeur visualise
        hvisu = round((3*l/4), 1)
        avisu = round(((2*atan(l/(2*d)))*(180/pi)), 1)
        focal = round((d*(lc/l)), 1)
        
        # envoie des rsultats dans les statictexts
        self.hauteur.SetLabel("%s m" %hvisu)
        self.angle.SetLabel(u"%s " %avisu)
        self.focale.SetLabel("%s mm" %focal)
        
        


class OngletZoom(wx.Panel):
    """Calcul d'un champ mini/maxi en fonction d'un objectif"""
    def __init__(self, parent):
        wx.Panel.__init__(self, parent)
        self.parent = parent
        
        
        ############## cration du sizer principal ###############
        
        self.gbs = wx.GridBagSizer(hgap=5, vgap=5)
        
        ############## cration des widgets #####################
        
        # spinctrl de choix de la distance
        labelDistance = wx.StaticText(self, -1, u"Distance sujet/objectif (en m): ")
        self.distance = wx.SpinCtrl(self, -1, "")
        self.distance.SetRange(1,999)
        self.distance.SetValue(20)
        
        # Choix de slection du capteur
        labelCapteur = wx.StaticText(self, -1, u"Format du capteur : ")
        self.lbCapteur = wx.Choice(self, -1, (-1, -1), choices = listeCapteur)
        self.lbCapteur.SetStringSelection(listeCapteur[1])
        
        # Choix de slection de la focale mini
        labelFocaleMini = wx.StaticText(self, -1, u"Focale mini (mm): ")
        self.lbFocaleMini = wx.Choice(self, -1, (-1, -1), choices = listeFocale)
        self.lbFocaleMini.SetStringSelection(listeFocale[0])
        
        # Choix de slection de la focale maxi
        labelFocaleMaxi = wx.StaticText(self, -1, u"Focale maxi (mm): ")
        self.lbFocaleMaxi = wx.Choice(self, -1, choices = listeFocale)
        self.lbFocaleMaxi.SetStringSelection(listeFocale[21])
        
        # Rsultats
        labelHauteurMini = wx.StaticText(self, -1, u"Hauteur visualise mini : ")
        self.hauteurMini = wx.StaticText(self, -1, u"... m", size=(100,25))
        self.hauteurMini.SetForegroundColour('red')
        self.hauteurMini.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        
        labelHauteurMaxi = wx.StaticText(self, -1, u"Hauteur visualise maxi : ")
        self.hauteurMaxi = wx.StaticText(self, -1, u"... m")
        self.hauteurMaxi.SetForegroundColour('blue')
        self.hauteurMaxi.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        
        labelLargeurMini = wx.StaticText(self, -1, u"Largeur visualise mini : ")
        self.LargeurMini = wx.StaticText(self, -1, u"... m")
        self.LargeurMini.SetForegroundColour('red')
        self.LargeurMini.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        
        labelLargeurMaxi = wx.StaticText(self, -1, u"Largeur visualise maxi : ")
        self.LargeurMaxi = wx.StaticText(self, -1, u"... m")
        self.LargeurMaxi.SetForegroundColour('blue')
        self.LargeurMaxi.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        
        labelAngleMini = wx.StaticText(self, -1, u"Angle de vision mini : ")
        self.angleMini = wx.StaticText(self, -1, u"... ")
        self.angleMini.SetForegroundColour('red')
        self.angleMini.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        
        labelAngleMaxi = wx.StaticText(self, -1, u"Angle de vision maxi : ")
        self.angleMaxi = wx.StaticText(self, -1, u"... ")
        self.angleMaxi.SetForegroundColour('blue')
        self.angleMaxi.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        
        # Bouton calcul
        self.btnCalc = wx.Button(self ,-1, "Calculer")
        self.btnCalc.SetBackgroundColour("yellow")
        self.btnCalc.SetDefault()
        self.Bind(wx.EVT_BUTTON, self.onCalcul, self.btnCalc)
        
        ############### Ajout des wigets au sizer ####################
        self.gbs.Add(labelDistance, (0,0))
        self.gbs.Add(self.distance, (0,1))
        self.gbs.Add(labelCapteur, (1,0))
        self.gbs.Add(self.lbCapteur, (1,1))
        self.gbs.Add(labelFocaleMini, (2,0))
        self.gbs.Add(self.lbFocaleMini, (2,1))
        self.gbs.Add(labelFocaleMaxi, (3,0))
        self.gbs.Add(self.lbFocaleMaxi, (3,1))
        
        self.gbs.Add(self.btnCalc, (4,1))
        
        self.gbs.Add(labelHauteurMini, (0,3))
        self.gbs.Add(self.hauteurMini, (0,4))
        self.gbs.Add(labelHauteurMaxi, (1,3))
        self.gbs.Add(self.hauteurMaxi, (1,4))
        self.gbs.Add(labelLargeurMini, (2,3))
        self.gbs.Add(self.LargeurMini, (2,4))
        self.gbs.Add(labelLargeurMaxi, (3,3))
        self.gbs.Add(self.LargeurMaxi, (3,4))
        self.gbs.Add(labelAngleMini, (4,3))
        self.gbs.Add(self.angleMini, (4,4))
        self.gbs.Add(labelAngleMaxi, (5,3))
        self.gbs.Add(self.angleMaxi, (5,4))
        
        
        self.SetSizerAndFit(self.gbs)
        
    def onCalcul(self, evt):
        # on rcupre les valeurs ncessaires au calcul
        d = self.distance.GetValue()
        capteur = self.lbCapteur.GetStringSelection()
        focMini = float(self.lbFocaleMini.GetStringSelection())
        focMaxi = float(self.lbFocaleMaxi.GetStringSelection())
        # on donne les valeurs  la largeur cible (lc) et la hauteur cible (hc) du capteur
        if capteur == listeCapteur[0]:
            lc = 3.6
            hc = 2.7
        if capteur == listeCapteur[1]:
            lc = 4.8
            hc = 3.6
        if capteur == listeCapteur[2]:
            lc = 6.4
            hc = 4.8
        if capteur == listeCapteur[3]:
            lc = 8.8
            hc = 6.6
        
        # Calcul des largeurs visualises
        lMinVisu = round((lc*d/focMaxi), 1)
        lMaxVisu = round((lc*d/focMini), 1)
        # Calcul des hauteurs visualises
        hMinVisu = round((3*lMinVisu/4), 1)
        hMaxVisu = round((3*lMaxVisu/4), 1)
        # Calculs des angles
        aMinVisu = round(((2*atan(lMinVisu/(2*d)))*(180/pi)), 1)
        aMaxVisu = round(((2*atan(lMaxVisu/(2*d)))*(180/pi)), 1)
        
        # envoi les rsultats dans les statictexts
        self.LargeurMini.SetLabel("%s m" %lMinVisu)
        self.LargeurMaxi.SetLabel("%s m" %lMaxVisu)
        self.hauteurMini.SetLabel("%s m" %hMinVisu)
        self.hauteurMaxi.SetLabel("%s m" %hMaxVisu)
        self.angleMini.SetLabel(u"%s " %aMinVisu)
        self.angleMaxi.SetLabel(u"%s " %aMaxVisu)



class Video(wx.Frame):
    def __init__(self, parent):
        wx.Frame.__init__(self, parent, title=u"Vido %s"%version, 
                          style=wx.DEFAULT_FRAME_STYLE 
                          ^(wx.RESIZE_BORDER | wx.MAXIMIZE_BOX))
        self.parent = parent
        
         # Ajout d'une barre d'tat
        self.CreateStatusBar()
        self.SetStatusText(statusText)    
        
        # Cration d'un panel pour y placer les Widgets
        panel = wx.Panel(self)
        
        # Cration d'un sizer pour organiser les widgets
        sizer = wx.GridBagSizer(hgap=5, vgap=5)
        
        # Ajout du notebook au panel
        self.nb = wx.Notebook(panel)#, size=(500,500))
        
        # Cration des onglets
        self.page1 = OngletChamp(self.nb)
        self.page2 = OngletHauteur(self.nb)
        self.page3 = OngletLargeur(self.nb)
        self.page4 = OngletZoom(self.nb)
        
        # Ajout des onglets au notebook
        self.nb.AddPage(self.page1, "Champ de vision")
        self.nb.AddPage(self.page2, u"Largeur et focale")
        self.nb.AddPage(self.page3, u"hauteur et focale")
        self.nb.AddPage(self.page4, "Zoom")
        
        self.Bind(wx.EVT_NOTEBOOK_PAGE_CHANGED, self.chgOnglet, self.nb)
        
        # Bouton quitter
        btnQuit = wx.Button(panel, wx.ID_CLOSE, "Quitter")
        self.Bind(wx.EVT_BUTTON, self.onQuitter, btnQuit)
        
        self.Bind(wx.EVT_CLOSE, self.onQuitter)
        
        # Ajout des Widgets au sizer
        sizer.Add(self.nb, (0,0),border=2)
        sizer.Add(btnQuit, (1,0))
        
        # Ajout du sizer au panel
        panel.SetSizerAndFit(sizer)
        self.SetClientSize(panel.GetSize())
        
        self.Bind(wx.EVT_CLOSE, self.onQuitter)
        
    def chgOnglet(self, evt):
        # mettre une aide en foncion de l'onglet dans la statusbar
        numOnglet = self.nb.GetSelection()
        if numOnglet == 0 :
            self.SetStatusText(statusText)
        if numOnglet == 1 :
            self.SetStatusText(u"Calcul de la largeur et de la focale en fonction de la hauteur  visualiser")
        if numOnglet == 2 :
            self.SetStatusText(u"Calcul de la hauteur et de la focale en fonction de la largeur  visualiser")
        if numOnglet == 3 :
            self.SetStatusText(u"Calcul d'un champ mini/maxi en fonction d'un objectif")
        
    def onQuitter(self, evt):
        """Quitter l'application"""
        self.parent.btnVideo.Enable(True)
        self.parent.menuModuleVideo.Enable(True)
        self.Destroy()
